@@ -43,6 +43,10 @@ func NewReportEventReceiver(tenantConfig *cautils.ConfigObj) *ReportEventReceive
 
 func (report *ReportEventReceiver) ActionSendReport(opaSessionObj *cautils.OPASessionObj) error {
 
+	if report.customerGUID == "" || report.clusterName == "" {
+		return fmt.Errorf("missing accout ID or cluster name. AccountID: '%s', Cluster name: '%s'", report.customerGUID, report.clusterName)
+	}
+
 	if err := report.prepareReport(opaSessionObj.PostureReport, opaSessionObj.AllResources); err != nil {
 		return err
 	}
@@ -54,13 +58,16 @@ func (report *ReportEventReceiver) SetCustomerGUID(customerGUID string) {
 }
 
 func (report *ReportEventReceiver) SetClusterName(clusterName string) {
-	report.clusterName = clusterName
+	report.clusterName = cautils.AdoptClusterName(clusterName) // clean cluster name
 }
 
 func (report *ReportEventReceiver) prepareReport(postureReport *reporthandling.PostureReport, allResources map[string]workloadinterface.IMetadata) error {
 	report.initEventReceiverURL()
 	host := hostToString(report.eventReceiverURL, postureReport.ReportID)
 
+	cautils.StartSpinner()
+	defer cautils.StopSpinner()
+
 	// send framework results
 	if err := report.sendReport(host, postureReport); err != nil {
 		return err
@@ -116,14 +123,14 @@ func (report *ReportEventReceiver) sendReport(host string, postureReport *report
 }
 
 func (report *ReportEventReceiver) DisplayReportURL() {
-	message := "You can see the results in a user-friendly UI, choose your preferred compliance framework, check risk results history and trends, manage exceptions, get remediation recommendations and much more by registering here: "
+	message := "You can see the results in a user-friendly UI, choose your preferred compliance framework, check risk results history and trends, manage exceptions, get remediation recommendations and much more by registering here:"
 
 	u := url.URL{}
 	u.Scheme = "https"
 	u.Host = getter.GetArmoAPIConnector().GetFrontendURL()
 
 	if report.customerAdminEMail != "" {
-		cautils.InfoTextDisplay(os.Stdout, "\n\n"+message+u.String()+"\n\n")
+		cautils.InfoTextDisplay(os.Stdout, fmt.Sprintf("\n\n%s %s/risk/%s\n(Account: %s)\n\n", message, u.String(), report.clusterName, report.customerGUID))
 		return
 	}
 	u.Path = "account/sign-up"
@@ -132,5 +139,5 @@ func (report *ReportEventReceiver) DisplayReportURL() {
 	q.Add("customerGUID", report.customerGUID)
 
 	u.RawQuery = q.Encode()
-	cautils.InfoTextDisplay(os.Stdout, "\n\n"+message+u.String()+"\n\n")
+	cautils.InfoTextDisplay(os.Stdout, fmt.Sprintf("\n\n%s %s\n\n", message, u.String()))
 }
